#
# spec file for package python-pulsectl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without test
Name:           python-pulsectl
Version:        24.12.0
Release:        1.1
Summary:        Python high-level interface and ctypes-based bindings for PulseAudio (libpulse)
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/mk-fg/python-pulse-control
Source:         https://files.pythonhosted.org/packages/source/p/pulsectl/pulsectl-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
BuildArch:      noarch
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
%if %{with test}
BuildRequires:  libpulse-devel
BuildRequires:  pulseaudio
BuildRequires:  pulseaudio-utils
%endif
%python_subpackages

%description
Python (3.x and 2.x) high-level interface and ctypes-based bindings for
PulseAudio (libpulse), mostly focused on mixer-like controls and
introspection-related operations (as opposed to e.g. submitting sound samples to
play, player-like client).

%prep
%setup -q -n pulsectl-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pyunittest discover
%endif

%files %{python_files}
%license COPYING
%doc CHANGES.rst README.rst
%{python_sitelib}/pulsectl
%{python_sitelib}/pulsectl-%{version}*-info

%changelog
* Wed Feb 26 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 24.12.0
  * expose profile_list (and n_profiles too) for PulseCardPortInfo
  * Setup/changelog version bump
- Use Python 3.11 on SLE-15 by default
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 24.11.0:
  * pulsectl: check return from pa_context_new to be not NULL
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 24.8.0:
  * docstring fix
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 24.4.0:
  * Add more obvious sink_default_get/source_default_get wrappers
    around server_info #81
* Sat Dec  9 2023 Dirk Müller <dmueller@suse.com>
- update to 23.5.2:
  * README and metadata updates
* Fri Feb 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- update to 22.3.2
  * 21.10.4: Add channel_list_enum to compare channel_list values with
    something in a typo-free way, expose channel_list_raw with C enum
    values [#66].
  * 21.5.0: Fix PA_VOLUME_MAX and PA_VOLUME_UI_MAX values, both were
    incorrect [#53].
* Fri Apr 16 2021 Markéta Machová <mmachova@suse.com>
- update to 21.3.4
  * Add timeout= option for connect() method [#48].
  * Expose "base_volume" (alsa volume level) attribute for sinks/sources [#47].
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 20.2.4
  * Add pulse.get_card_by_name() wrapper [#38].
  * Expose "corked" bool attr in PulseSinkInputInfo and PulseSourceOutputInfo [#37].
* Mon Jan 20 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 20.1.2
  * add pulse.play_sample() - server-side stored sample playback
  * Add pulse.get_peak_sample() func for getting volume peak within timespan
* Wed Jun  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 18.12.5
  * pulse.connect() can now be used to reconnect to same server
  * _pulse_op_cb: check connected state instead of _loop_stop
  * _pulse_op_cb: fix hang if daemon dies
  * tests: use "-F /dev/stdin" instead of -C for dummy pulse instance
  * Add pulsectl.lookup util submodule
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Jan  5 2018 alarrosa@suse.com
- Update to version 17.12.2
  * Use pa_card_profile_info2 / profiles2 introspection API.
  * Only adds one "available" property to PulseCardProfileInfo.
    Requires pulseaudio/libpulse 5.0+.
* Fri Nov 10 2017 alarrosa@suse.com
- Initial release of python-pulsectl 17.9.3
